#!/bin/sh

set -e

failure() { echo "$1";  exit 1; }

fwinfo() {
	awk "/$1/ { print \$2 }" /etc/fw-info | tr -d '",'
}

if [ -f /etc/fw-info ]; then
	plat=$(fwinfo platform)
	inst_type=$(fwinfo install_type)

	if [ -n "$plat" ] && [ "$plat" != "bb" ]; then
		failure "Wrong firmware update file, target platform is bb"
	fi

	if [ -n "$inst_type" ] && [ "$inst_type" != "sd" ]; then
		failure "Wrong firmware update file, target installation type is sd"
	fi
fi

if [ -f fw.md5 ]; then
	echo "Verifying md5 checksums"
    md5sum -s -c fw.md5 > /dev/null 2>&1
fi

if [ ! -d /mnt/mmc ]; then
	echo "SD card not mounted"
	exit 1
fi

if [ -e BOOT.bin ]; then
	echo "Updating BOOT.bin"
	cp -f BOOT.bin /mnt/mmc > /dev/null 2>&1
fi

if [ -e devtree.dtb ]; then
	echo "Updating devtree.dtb"
	cp -f devtree.dtb /mnt/mmc > /dev/null 2>&1
	cp -f devtree.dtb.sig /mnt/mmc > /dev/null 2>&1
fi

if [ -e miner.btm ]; then
	echo "Updating miner.btm"
	cp -f miner.btm /mnt/mmc > /dev/null 2>&1
	cp -f miner.btm.sig /mnt/mmc > /dev/null 2>&1
fi

if [ -e uEnv.txt ]; then
	echo "Updating uEnv.txt"
	cp -f uEnv.txt /mnt/mmc > /dev/null 2>&1
fi

if [ -e uImage ]; then
	echo "Updating uImage"
	cp -f uImage /mnt/mmc > /dev/null 2>&1
	cp -f uImage.sig /mnt/mmc > /dev/null 2>&1
fi

if [ -e uramdisk.image.gz ]; then
	echo "Updating uramdisk.image.gz"
	cp -f uramdisk.image.gz /mnt/mmc > /dev/null 2>&1
	cp -f uramdisk.image.gz.sig /mnt/mmc > /dev/null 2>&1
fi

sync